summaryrefslogtreecommitdiffstats
path: root/Http/Authentication/AuthenticationFailureHandlerInterface.php
diff options
context:
space:
mode:
Diffstat (limited to 'Http/Authentication/AuthenticationFailureHandlerInterface.php')
-rw-r--r--Http/Authentication/AuthenticationFailureHandlerInterface.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/Http/Authentication/AuthenticationFailureHandlerInterface.php b/Http/Authentication/AuthenticationFailureHandlerInterface.php
index 4e6c694..b35c232 100644
--- a/Http/Authentication/AuthenticationFailureHandlerInterface.php
+++ b/Http/Authentication/AuthenticationFailureHandlerInterface.php
@@ -2,7 +2,7 @@
namespace Symfony\Component\Security\Http\Authentication;
-use Symfony\Component\HttpKernel\Event\RequestEventArgs;
+use Symfony\Component\HttpKernel\Event\GetResponseEventArgs;
use Symfony\Component\Security\Core\Exception\AuthenticationException;
use Symfony\Component\HttpFoundation\Request;
@@ -22,12 +22,12 @@ interface AuthenticationFailureHandlerInterface
* called by authentication listeners inheriting from
* AbstractAuthenticationListener.
*
* @param RequestEventArgs $eventArgs the "onCoreSecurity" event, this event always
* has the kernel as target
* @param Request $request
* @param AuthenticationException $exception
*
* @return Response the response to return
*/
- function onAuthenticationFailure(RequestEventArgs $eventArgs, Request $request, AuthenticationException $exception);
+ function onAuthenticationFailure(GetResponseEventArgs $eventArgs, Request $request, AuthenticationException $exception);
} \ No newline at end of file
@@ -22,12 +22,12 @@ interface AuthenticationFailureHandlerInterface
* AbstractAuthenticationListener.
*
- * @param RequestEventArgs $eventArgs the "onCoreSecurity" event, this event always
+ * @param GetResponseEventArgs $eventArgs the "onCoreSecurity" event, this event always
* has the kernel as target
* @param Request $request